indicatortools.TimeSignature
============================

.. abjad-lineage:: abjad.tools.indicatortools.TimeSignature.TimeSignature

.. autoclass:: abjad.tools.indicatortools.TimeSignature.TimeSignature

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.indicatortools.TimeSignature.TimeSignature.denominator
      ~abjad.tools.indicatortools.TimeSignature.TimeSignature.duration
      ~abjad.tools.indicatortools.TimeSignature.TimeSignature.has_non_power_of_two_denominator
      ~abjad.tools.indicatortools.TimeSignature.TimeSignature.implied_prolation
      ~abjad.tools.indicatortools.TimeSignature.TimeSignature.numerator
      ~abjad.tools.indicatortools.TimeSignature.TimeSignature.pair
      ~abjad.tools.indicatortools.TimeSignature.TimeSignature.partial
      ~abjad.tools.indicatortools.TimeSignature.TimeSignature.suppress
      ~abjad.tools.indicatortools.TimeSignature.TimeSignature.with_power_of_two_denominator
      ~abjad.tools.indicatortools.TimeSignature.TimeSignature.__copy__
      ~abjad.tools.indicatortools.TimeSignature.TimeSignature.__eq__
      ~abjad.tools.indicatortools.TimeSignature.TimeSignature.__format__
      ~abjad.tools.indicatortools.TimeSignature.TimeSignature.__ge__
      ~abjad.tools.indicatortools.TimeSignature.TimeSignature.__gt__
      ~abjad.tools.indicatortools.TimeSignature.TimeSignature.__hash__
      ~abjad.tools.indicatortools.TimeSignature.TimeSignature.__le__
      ~abjad.tools.indicatortools.TimeSignature.TimeSignature.__lt__
      ~abjad.tools.indicatortools.TimeSignature.TimeSignature.__ne__
      ~abjad.tools.indicatortools.TimeSignature.TimeSignature.__repr__
      ~abjad.tools.indicatortools.TimeSignature.TimeSignature.__str__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.indicatortools.TimeSignature.TimeSignature.denominator
   :noindex:

.. autoattribute:: abjad.tools.indicatortools.TimeSignature.TimeSignature.duration
   :noindex:

.. autoattribute:: abjad.tools.indicatortools.TimeSignature.TimeSignature.has_non_power_of_two_denominator
   :noindex:

.. autoattribute:: abjad.tools.indicatortools.TimeSignature.TimeSignature.implied_prolation
   :noindex:

.. autoattribute:: abjad.tools.indicatortools.TimeSignature.TimeSignature.numerator
   :noindex:

.. autoattribute:: abjad.tools.indicatortools.TimeSignature.TimeSignature.pair
   :noindex:

.. autoattribute:: abjad.tools.indicatortools.TimeSignature.TimeSignature.partial
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.indicatortools.TimeSignature.TimeSignature.suppress
   :noindex:

Methods
-------

.. automethod:: abjad.tools.indicatortools.TimeSignature.TimeSignature.with_power_of_two_denominator
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.indicatortools.TimeSignature.TimeSignature.__copy__
   :noindex:

.. automethod:: abjad.tools.indicatortools.TimeSignature.TimeSignature.__eq__
   :noindex:

.. automethod:: abjad.tools.indicatortools.TimeSignature.TimeSignature.__format__
   :noindex:

.. automethod:: abjad.tools.indicatortools.TimeSignature.TimeSignature.__ge__
   :noindex:

.. automethod:: abjad.tools.indicatortools.TimeSignature.TimeSignature.__gt__
   :noindex:

.. automethod:: abjad.tools.indicatortools.TimeSignature.TimeSignature.__hash__
   :noindex:

.. automethod:: abjad.tools.indicatortools.TimeSignature.TimeSignature.__le__
   :noindex:

.. automethod:: abjad.tools.indicatortools.TimeSignature.TimeSignature.__lt__
   :noindex:

.. automethod:: abjad.tools.indicatortools.TimeSignature.TimeSignature.__ne__
   :noindex:

.. automethod:: abjad.tools.indicatortools.TimeSignature.TimeSignature.__repr__
   :noindex:

.. automethod:: abjad.tools.indicatortools.TimeSignature.TimeSignature.__str__
   :noindex:
